# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proio/model/mc/mc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proio/model/mc/mc.proto',
  package='proio.model.mc',
  syntax='proto2',
  serialized_options=_b('\n\013proio.modelB\002McZ\002mc'),
  serialized_pb=_b('\n\x17proio/model/mc/mc.proto\x12\x0eproio.model.mc\"\xfc\x01\n\x08Particle\x12\x0e\n\x06parent\x18\x01 \x03(\x04\x12\r\n\x05\x63hild\x18\x02 \x03(\x04\x12\x0b\n\x03pdg\x18\x03 \x01(\x11\x12%\n\x06vertex\x18\x04 \x01(\x0b\x32\x15.proio.model.mc.XYZTF\x12\x1f\n\x01p\x18\x05 \x01(\x0b\x32\x14.proio.model.mc.XYZF\x12\x0e\n\x06\x65nergy\x18\x06 \x01(\x02\x12\x0c\n\x04mass\x18\x07 \x01(\x02\x12\x0e\n\x06\x63harge\x18\x08 \x01(\x11\x12\x0c\n\x04spin\x18\r \x01(\r\x12\x0e\n\x06status\x18\n \x01(\x11\x12\x0f\n\x07\x62\x61rcode\x18\x0b \x01(\x11\x12\n\n\x02id\x18\x0c \x01(\r\x12\x13\n\x0bspin_sint32\x18\t \x01(\x11\"\xe7\x02\n\x0fPackedParticles\x12\x0e\n\x02id\x18\x01 \x03(\rB\x02\x10\x01\x12\x0f\n\x03pdg\x18\x02 \x03(\x11\x42\x02\x10\x01\x12\x12\n\x06status\x18\x03 \x03(\rB\x02\x10\x01\x12\x10\n\x04mass\x18\x04 \x03(\x02\x42\x02\x10\x01\x12\x0e\n\x02Px\x18\x05 \x03(\x02\x42\x02\x10\x01\x12\x0e\n\x02Py\x18\x06 \x03(\x02\x42\x02\x10\x01\x12\x0e\n\x02Pz\x18\x07 \x03(\x02\x42\x02\x10\x01\x12\x13\n\x07parent1\x18\x08 \x03(\rB\x02\x10\x01\x12\x13\n\x07parent2\x18\t \x03(\rB\x02\x10\x01\x12\x12\n\x06\x63hild1\x18\n \x03(\rB\x02\x10\x01\x12\x12\n\x06\x63hild2\x18\x0b \x03(\rB\x02\x10\x01\x12\x13\n\x07\x62\x61rcode\x18\x0c \x03(\x11\x42\x02\x10\x01\x12\r\n\x01X\x18\r \x03(\x02\x42\x02\x10\x01\x12\r\n\x01Y\x18\x0e \x03(\x02\x42\x02\x10\x01\x12\r\n\x01Z\x18\x0f \x03(\x02\x42\x02\x10\x01\x12\r\n\x01T\x18\x10 \x03(\x02\x42\x02\x10\x01\x12\x12\n\x06weight\x18\x11 \x03(\x02\x42\x02\x10\x01\x12\x12\n\x06\x63harge\x18\x12 \x03(\x11\x42\x02\x10\x01\x12\x12\n\x06\x65nergy\x18\x13 \x03(\x02\x42\x02\x10\x01\"\x82\x02\n\x0eVarintParticle\x12\x0e\n\x06parent\x18\x01 \x03(\x04\x12\r\n\x05\x63hild\x18\x02 \x03(\x04\x12\x0b\n\x03pdg\x18\x03 \x01(\x11\x12%\n\x06vertex\x18\x04 \x01(\x0b\x32\x15.proio.model.mc.XYZTI\x12\x1f\n\x01p\x18\x05 \x01(\x0b\x32\x14.proio.model.mc.XYZI\x12\x0e\n\x06\x65nergy\x18\x06 \x01(\x04\x12\x0c\n\x04mass\x18\x07 \x01(\x04\x12\x0e\n\x06\x63harge\x18\x08 \x01(\x11\x12\x0c\n\x04spin\x18\r \x01(\r\x12\x0e\n\x06status\x18\n \x01(\x11\x12\x0f\n\x07\x62\x61rcode\x18\x0b \x01(\x11\x12\n\n\x02id\x18\x0c \x01(\r\x12\x13\n\x0bspin_sint32\x18\t \x01(\x11\"\xed\x02\n\x15VarintPackedParticles\x12\x0e\n\x02id\x18\x01 \x03(\rB\x02\x10\x01\x12\x0f\n\x03pdg\x18\x02 \x03(\x11\x42\x02\x10\x01\x12\x12\n\x06status\x18\x03 \x03(\rB\x02\x10\x01\x12\x10\n\x04mass\x18\x04 \x03(\x04\x42\x02\x10\x01\x12\x0e\n\x02Px\x18\x05 \x03(\x12\x42\x02\x10\x01\x12\x0e\n\x02Py\x18\x06 \x03(\x12\x42\x02\x10\x01\x12\x0e\n\x02Pz\x18\x07 \x03(\x12\x42\x02\x10\x01\x12\x13\n\x07parent1\x18\x08 \x03(\rB\x02\x10\x01\x12\x13\n\x07parent2\x18\t \x03(\rB\x02\x10\x01\x12\x12\n\x06\x63hild1\x18\n \x03(\rB\x02\x10\x01\x12\x12\n\x06\x63hild2\x18\x0b \x03(\rB\x02\x10\x01\x12\x13\n\x07\x62\x61rcode\x18\x0c \x03(\x11\x42\x02\x10\x01\x12\r\n\x01X\x18\r \x03(\x12\x42\x02\x10\x01\x12\r\n\x01Y\x18\x0e \x03(\x12\x42\x02\x10\x01\x12\r\n\x01Z\x18\x0f \x03(\x12\x42\x02\x10\x01\x12\r\n\x01T\x18\x10 \x03(\x04\x42\x02\x10\x01\x12\x12\n\x06weight\x18\x11 \x03(\x04\x42\x02\x10\x01\x12\x12\n\x06\x63harge\x18\x12 \x03(\x11\x42\x02\x10\x01\x12\x12\n\x06\x65nergy\x18\x13 \x03(\x04\x42\x02\x10\x01\"\xde\x02\n\x0cMCParameters\x12\x0e\n\x06number\x18\x01 \x01(\x04\x12\x11\n\tprocessid\x18\x02 \x01(\x05\x12\x0e\n\x06weight\x18\x03 \x01(\x01\x12=\n\tint_extra\x18\x04 \x03(\x0b\x32*.proio.model.mc.MCParameters.IntExtraEntry\x12\x41\n\x0b\x66loat_extra\x18\x05 \x03(\x0b\x32,.proio.model.mc.MCParameters.FloatExtraEntry\x1aI\n\rIntExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.proio.model.mc.ArrayInt:\x02\x38\x01\x1aN\n\x0f\x46loatExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.proio.model.mc.ArrayDouble:\x02\x38\x01\"\x19\n\x08\x41rrayInt\x12\r\n\x05value\x18\x01 \x03(\x11\"\x1c\n\x0b\x41rrayDouble\x12\r\n\x05value\x18\x01 \x03(\x01\"\xc9\x01\n\x11Pythia8Parameters\x12\x12\n\nweight_sum\x18\x01 \x01(\x01\x12\x16\n\x0emerging_weight\x18\x02 \x01(\x01\x12\x0e\n\x06pt_hat\x18\x03 \x01(\x01\x12\x10\n\x08\x61lpha_em\x18\x04 \x01(\x01\x12\x0f\n\x07\x61lpha_s\x18\x05 \x01(\x01\x12\x13\n\x0bscale_q_fac\x18\x06 \x01(\x01\x12\x0e\n\x06weight\x18\x07 \x01(\x01\x12\n\n\x02x1\x18\x08 \x01(\x01\x12\n\n\x02x2\x18\t \x01(\x01\x12\x0b\n\x03id1\x18\n \x01(\x04\x12\x0b\n\x03id2\x18\x0b \x01(\x04\"3\n\x05XYZTF\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01t\x18\x04 \x01(\x02\"3\n\x05XYZTI\x12\t\n\x01x\x18\x01 \x01(\x12\x12\t\n\x01y\x18\x02 \x01(\x12\x12\t\n\x01z\x18\x03 \x01(\x12\x12\t\n\x01t\x18\x04 \x01(\x04\"\'\n\x04XYZF\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"\'\n\x04XYZI\x12\t\n\x01x\x18\x01 \x01(\x12\x12\t\n\x01y\x18\x02 \x01(\x12\x12\t\n\x01z\x18\x03 \x01(\x12\x42\x15\n\x0bproio.modelB\x02McZ\x02mc')
)




_PARTICLE = _descriptor.Descriptor(
  name='Particle',
  full_name='proio.model.mc.Particle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='proio.model.mc.Particle.parent', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child', full_name='proio.model.mc.Particle.child', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdg', full_name='proio.model.mc.Particle.pdg', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertex', full_name='proio.model.mc.Particle.vertex', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p', full_name='proio.model.mc.Particle.p', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy', full_name='proio.model.mc.Particle.energy', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.mc.Particle.mass', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.mc.Particle.charge', index=7,
      number=8, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spin', full_name='proio.model.mc.Particle.spin', index=8,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='proio.model.mc.Particle.status', index=9,
      number=10, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='barcode', full_name='proio.model.mc.Particle.barcode', index=10,
      number=11, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='proio.model.mc.Particle.id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spin_sint32', full_name='proio.model.mc.Particle.spin_sint32', index=12,
      number=9, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=296,
)


_PACKEDPARTICLES = _descriptor.Descriptor(
  name='PackedParticles',
  full_name='proio.model.mc.PackedParticles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proio.model.mc.PackedParticles.id', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdg', full_name='proio.model.mc.PackedParticles.pdg', index=1,
      number=2, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='proio.model.mc.PackedParticles.status', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.mc.PackedParticles.mass', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Px', full_name='proio.model.mc.PackedParticles.Px', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Py', full_name='proio.model.mc.PackedParticles.Py', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Pz', full_name='proio.model.mc.PackedParticles.Pz', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent1', full_name='proio.model.mc.PackedParticles.parent1', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent2', full_name='proio.model.mc.PackedParticles.parent2', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child1', full_name='proio.model.mc.PackedParticles.child1', index=9,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child2', full_name='proio.model.mc.PackedParticles.child2', index=10,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='barcode', full_name='proio.model.mc.PackedParticles.barcode', index=11,
      number=12, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='X', full_name='proio.model.mc.PackedParticles.X', index=12,
      number=13, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Y', full_name='proio.model.mc.PackedParticles.Y', index=13,
      number=14, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Z', full_name='proio.model.mc.PackedParticles.Z', index=14,
      number=15, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='T', full_name='proio.model.mc.PackedParticles.T', index=15,
      number=16, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='proio.model.mc.PackedParticles.weight', index=16,
      number=17, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.mc.PackedParticles.charge', index=17,
      number=18, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy', full_name='proio.model.mc.PackedParticles.energy', index=18,
      number=19, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=658,
)


_VARINTPARTICLE = _descriptor.Descriptor(
  name='VarintParticle',
  full_name='proio.model.mc.VarintParticle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='proio.model.mc.VarintParticle.parent', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child', full_name='proio.model.mc.VarintParticle.child', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdg', full_name='proio.model.mc.VarintParticle.pdg', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertex', full_name='proio.model.mc.VarintParticle.vertex', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p', full_name='proio.model.mc.VarintParticle.p', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy', full_name='proio.model.mc.VarintParticle.energy', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.mc.VarintParticle.mass', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.mc.VarintParticle.charge', index=7,
      number=8, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spin', full_name='proio.model.mc.VarintParticle.spin', index=8,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='proio.model.mc.VarintParticle.status', index=9,
      number=10, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='barcode', full_name='proio.model.mc.VarintParticle.barcode', index=10,
      number=11, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='proio.model.mc.VarintParticle.id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spin_sint32', full_name='proio.model.mc.VarintParticle.spin_sint32', index=12,
      number=9, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=661,
  serialized_end=919,
)


_VARINTPACKEDPARTICLES = _descriptor.Descriptor(
  name='VarintPackedParticles',
  full_name='proio.model.mc.VarintPackedParticles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proio.model.mc.VarintPackedParticles.id', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdg', full_name='proio.model.mc.VarintPackedParticles.pdg', index=1,
      number=2, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='proio.model.mc.VarintPackedParticles.status', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.mc.VarintPackedParticles.mass', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Px', full_name='proio.model.mc.VarintPackedParticles.Px', index=4,
      number=5, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Py', full_name='proio.model.mc.VarintPackedParticles.Py', index=5,
      number=6, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Pz', full_name='proio.model.mc.VarintPackedParticles.Pz', index=6,
      number=7, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent1', full_name='proio.model.mc.VarintPackedParticles.parent1', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent2', full_name='proio.model.mc.VarintPackedParticles.parent2', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child1', full_name='proio.model.mc.VarintPackedParticles.child1', index=9,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child2', full_name='proio.model.mc.VarintPackedParticles.child2', index=10,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='barcode', full_name='proio.model.mc.VarintPackedParticles.barcode', index=11,
      number=12, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='X', full_name='proio.model.mc.VarintPackedParticles.X', index=12,
      number=13, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Y', full_name='proio.model.mc.VarintPackedParticles.Y', index=13,
      number=14, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Z', full_name='proio.model.mc.VarintPackedParticles.Z', index=14,
      number=15, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='T', full_name='proio.model.mc.VarintPackedParticles.T', index=15,
      number=16, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='proio.model.mc.VarintPackedParticles.weight', index=16,
      number=17, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.mc.VarintPackedParticles.charge', index=17,
      number=18, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy', full_name='proio.model.mc.VarintPackedParticles.energy', index=18,
      number=19, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=1287,
)


_MCPARAMETERS_INTEXTRAENTRY = _descriptor.Descriptor(
  name='IntExtraEntry',
  full_name='proio.model.mc.MCParameters.IntExtraEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proio.model.mc.MCParameters.IntExtraEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.model.mc.MCParameters.IntExtraEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1487,
  serialized_end=1560,
)

_MCPARAMETERS_FLOATEXTRAENTRY = _descriptor.Descriptor(
  name='FloatExtraEntry',
  full_name='proio.model.mc.MCParameters.FloatExtraEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proio.model.mc.MCParameters.FloatExtraEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.model.mc.MCParameters.FloatExtraEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1562,
  serialized_end=1640,
)

_MCPARAMETERS = _descriptor.Descriptor(
  name='MCParameters',
  full_name='proio.model.mc.MCParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number', full_name='proio.model.mc.MCParameters.number', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processid', full_name='proio.model.mc.MCParameters.processid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='proio.model.mc.MCParameters.weight', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_extra', full_name='proio.model.mc.MCParameters.int_extra', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_extra', full_name='proio.model.mc.MCParameters.float_extra', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MCPARAMETERS_INTEXTRAENTRY, _MCPARAMETERS_FLOATEXTRAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1290,
  serialized_end=1640,
)


_ARRAYINT = _descriptor.Descriptor(
  name='ArrayInt',
  full_name='proio.model.mc.ArrayInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.model.mc.ArrayInt.value', index=0,
      number=1, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1642,
  serialized_end=1667,
)


_ARRAYDOUBLE = _descriptor.Descriptor(
  name='ArrayDouble',
  full_name='proio.model.mc.ArrayDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.model.mc.ArrayDouble.value', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1669,
  serialized_end=1697,
)


_PYTHIA8PARAMETERS = _descriptor.Descriptor(
  name='Pythia8Parameters',
  full_name='proio.model.mc.Pythia8Parameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight_sum', full_name='proio.model.mc.Pythia8Parameters.weight_sum', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merging_weight', full_name='proio.model.mc.Pythia8Parameters.merging_weight', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pt_hat', full_name='proio.model.mc.Pythia8Parameters.pt_hat', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alpha_em', full_name='proio.model.mc.Pythia8Parameters.alpha_em', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alpha_s', full_name='proio.model.mc.Pythia8Parameters.alpha_s', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale_q_fac', full_name='proio.model.mc.Pythia8Parameters.scale_q_fac', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='proio.model.mc.Pythia8Parameters.weight', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='x1', full_name='proio.model.mc.Pythia8Parameters.x1', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='x2', full_name='proio.model.mc.Pythia8Parameters.x2', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id1', full_name='proio.model.mc.Pythia8Parameters.id1', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id2', full_name='proio.model.mc.Pythia8Parameters.id2', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1700,
  serialized_end=1901,
)


_XYZTF = _descriptor.Descriptor(
  name='XYZTF',
  full_name='proio.model.mc.XYZTF',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.mc.XYZTF.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.mc.XYZTF.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.mc.XYZTF.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t', full_name='proio.model.mc.XYZTF.t', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1903,
  serialized_end=1954,
)


_XYZTI = _descriptor.Descriptor(
  name='XYZTI',
  full_name='proio.model.mc.XYZTI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.mc.XYZTI.x', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.mc.XYZTI.y', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.mc.XYZTI.z', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t', full_name='proio.model.mc.XYZTI.t', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1956,
  serialized_end=2007,
)


_XYZF = _descriptor.Descriptor(
  name='XYZF',
  full_name='proio.model.mc.XYZF',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.mc.XYZF.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.mc.XYZF.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.mc.XYZF.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2009,
  serialized_end=2048,
)


_XYZI = _descriptor.Descriptor(
  name='XYZI',
  full_name='proio.model.mc.XYZI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.mc.XYZI.x', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.mc.XYZI.y', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.mc.XYZI.z', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2050,
  serialized_end=2089,
)

_PARTICLE.fields_by_name['vertex'].message_type = _XYZTF
_PARTICLE.fields_by_name['p'].message_type = _XYZF
_VARINTPARTICLE.fields_by_name['vertex'].message_type = _XYZTI
_VARINTPARTICLE.fields_by_name['p'].message_type = _XYZI
_MCPARAMETERS_INTEXTRAENTRY.fields_by_name['value'].message_type = _ARRAYINT
_MCPARAMETERS_INTEXTRAENTRY.containing_type = _MCPARAMETERS
_MCPARAMETERS_FLOATEXTRAENTRY.fields_by_name['value'].message_type = _ARRAYDOUBLE
_MCPARAMETERS_FLOATEXTRAENTRY.containing_type = _MCPARAMETERS
_MCPARAMETERS.fields_by_name['int_extra'].message_type = _MCPARAMETERS_INTEXTRAENTRY
_MCPARAMETERS.fields_by_name['float_extra'].message_type = _MCPARAMETERS_FLOATEXTRAENTRY
DESCRIPTOR.message_types_by_name['Particle'] = _PARTICLE
DESCRIPTOR.message_types_by_name['PackedParticles'] = _PACKEDPARTICLES
DESCRIPTOR.message_types_by_name['VarintParticle'] = _VARINTPARTICLE
DESCRIPTOR.message_types_by_name['VarintPackedParticles'] = _VARINTPACKEDPARTICLES
DESCRIPTOR.message_types_by_name['MCParameters'] = _MCPARAMETERS
DESCRIPTOR.message_types_by_name['ArrayInt'] = _ARRAYINT
DESCRIPTOR.message_types_by_name['ArrayDouble'] = _ARRAYDOUBLE
DESCRIPTOR.message_types_by_name['Pythia8Parameters'] = _PYTHIA8PARAMETERS
DESCRIPTOR.message_types_by_name['XYZTF'] = _XYZTF
DESCRIPTOR.message_types_by_name['XYZTI'] = _XYZTI
DESCRIPTOR.message_types_by_name['XYZF'] = _XYZF
DESCRIPTOR.message_types_by_name['XYZI'] = _XYZI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Particle = _reflection.GeneratedProtocolMessageType('Particle', (_message.Message,), dict(
  DESCRIPTOR = _PARTICLE,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.Particle)
  ))
_sym_db.RegisterMessage(Particle)

PackedParticles = _reflection.GeneratedProtocolMessageType('PackedParticles', (_message.Message,), dict(
  DESCRIPTOR = _PACKEDPARTICLES,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.PackedParticles)
  ))
_sym_db.RegisterMessage(PackedParticles)

VarintParticle = _reflection.GeneratedProtocolMessageType('VarintParticle', (_message.Message,), dict(
  DESCRIPTOR = _VARINTPARTICLE,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.VarintParticle)
  ))
_sym_db.RegisterMessage(VarintParticle)

VarintPackedParticles = _reflection.GeneratedProtocolMessageType('VarintPackedParticles', (_message.Message,), dict(
  DESCRIPTOR = _VARINTPACKEDPARTICLES,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.VarintPackedParticles)
  ))
_sym_db.RegisterMessage(VarintPackedParticles)

MCParameters = _reflection.GeneratedProtocolMessageType('MCParameters', (_message.Message,), dict(

  IntExtraEntry = _reflection.GeneratedProtocolMessageType('IntExtraEntry', (_message.Message,), dict(
    DESCRIPTOR = _MCPARAMETERS_INTEXTRAENTRY,
    __module__ = 'proio.model.mc.mc_pb2'
    # @@protoc_insertion_point(class_scope:proio.model.mc.MCParameters.IntExtraEntry)
    ))
  ,

  FloatExtraEntry = _reflection.GeneratedProtocolMessageType('FloatExtraEntry', (_message.Message,), dict(
    DESCRIPTOR = _MCPARAMETERS_FLOATEXTRAENTRY,
    __module__ = 'proio.model.mc.mc_pb2'
    # @@protoc_insertion_point(class_scope:proio.model.mc.MCParameters.FloatExtraEntry)
    ))
  ,
  DESCRIPTOR = _MCPARAMETERS,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.MCParameters)
  ))
_sym_db.RegisterMessage(MCParameters)
_sym_db.RegisterMessage(MCParameters.IntExtraEntry)
_sym_db.RegisterMessage(MCParameters.FloatExtraEntry)

ArrayInt = _reflection.GeneratedProtocolMessageType('ArrayInt', (_message.Message,), dict(
  DESCRIPTOR = _ARRAYINT,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.ArrayInt)
  ))
_sym_db.RegisterMessage(ArrayInt)

ArrayDouble = _reflection.GeneratedProtocolMessageType('ArrayDouble', (_message.Message,), dict(
  DESCRIPTOR = _ARRAYDOUBLE,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.ArrayDouble)
  ))
_sym_db.RegisterMessage(ArrayDouble)

Pythia8Parameters = _reflection.GeneratedProtocolMessageType('Pythia8Parameters', (_message.Message,), dict(
  DESCRIPTOR = _PYTHIA8PARAMETERS,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.Pythia8Parameters)
  ))
_sym_db.RegisterMessage(Pythia8Parameters)

XYZTF = _reflection.GeneratedProtocolMessageType('XYZTF', (_message.Message,), dict(
  DESCRIPTOR = _XYZTF,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.XYZTF)
  ))
_sym_db.RegisterMessage(XYZTF)

XYZTI = _reflection.GeneratedProtocolMessageType('XYZTI', (_message.Message,), dict(
  DESCRIPTOR = _XYZTI,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.XYZTI)
  ))
_sym_db.RegisterMessage(XYZTI)

XYZF = _reflection.GeneratedProtocolMessageType('XYZF', (_message.Message,), dict(
  DESCRIPTOR = _XYZF,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.XYZF)
  ))
_sym_db.RegisterMessage(XYZF)

XYZI = _reflection.GeneratedProtocolMessageType('XYZI', (_message.Message,), dict(
  DESCRIPTOR = _XYZI,
  __module__ = 'proio.model.mc.mc_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.mc.XYZI)
  ))
_sym_db.RegisterMessage(XYZI)


DESCRIPTOR._options = None
_PACKEDPARTICLES.fields_by_name['id']._options = None
_PACKEDPARTICLES.fields_by_name['pdg']._options = None
_PACKEDPARTICLES.fields_by_name['status']._options = None
_PACKEDPARTICLES.fields_by_name['mass']._options = None
_PACKEDPARTICLES.fields_by_name['Px']._options = None
_PACKEDPARTICLES.fields_by_name['Py']._options = None
_PACKEDPARTICLES.fields_by_name['Pz']._options = None
_PACKEDPARTICLES.fields_by_name['parent1']._options = None
_PACKEDPARTICLES.fields_by_name['parent2']._options = None
_PACKEDPARTICLES.fields_by_name['child1']._options = None
_PACKEDPARTICLES.fields_by_name['child2']._options = None
_PACKEDPARTICLES.fields_by_name['barcode']._options = None
_PACKEDPARTICLES.fields_by_name['X']._options = None
_PACKEDPARTICLES.fields_by_name['Y']._options = None
_PACKEDPARTICLES.fields_by_name['Z']._options = None
_PACKEDPARTICLES.fields_by_name['T']._options = None
_PACKEDPARTICLES.fields_by_name['weight']._options = None
_PACKEDPARTICLES.fields_by_name['charge']._options = None
_PACKEDPARTICLES.fields_by_name['energy']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['id']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['pdg']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['status']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['mass']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['Px']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['Py']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['Pz']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['parent1']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['parent2']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['child1']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['child2']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['barcode']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['X']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['Y']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['Z']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['T']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['weight']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['charge']._options = None
_VARINTPACKEDPARTICLES.fields_by_name['energy']._options = None
_MCPARAMETERS_INTEXTRAENTRY._options = None
_MCPARAMETERS_FLOATEXTRAENTRY._options = None
# @@protoc_insertion_point(module_scope)
