# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proio/model/example/example.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proio/model/example/example.proto',
  package='proio.model.example',
  syntax='proto3',
  serialized_options=_b('\n\013proio.modelB\007ExampleZ\007example'),
  serialized_pb=_b('\n!proio/model/example/example.proto\x12\x13proio.model.example\"\xa6\x01\n\x08Particle\x12\x0e\n\x06parent\x18\x01 \x03(\x04\x12\r\n\x05\x63hild\x18\x02 \x03(\x04\x12\x0b\n\x03pdg\x18\x03 \x01(\x11\x12*\n\x06vertex\x18\x04 \x01(\x0b\x32\x1a.proio.model.example.XYZTF\x12$\n\x01p\x18\x05 \x01(\x0b\x32\x19.proio.model.example.XYZF\x12\x0c\n\x04mass\x18\x06 \x01(\x02\x12\x0e\n\x06\x63harge\x18\x07 \x01(\x11\"\xac\x01\n\x0eVarintParticle\x12\x0e\n\x06parent\x18\x01 \x03(\x04\x12\r\n\x05\x63hild\x18\x02 \x03(\x04\x12\x0b\n\x03pdg\x18\x03 \x01(\x11\x12*\n\x06vertex\x18\x04 \x01(\x0b\x32\x1a.proio.model.example.XYZTI\x12$\n\x01p\x18\x05 \x01(\x0b\x32\x19.proio.model.example.XYZI\x12\x0c\n\x04mass\x18\x06 \x01(\r\x12\x0e\n\x06\x63harge\x18\x07 \x01(\x11\"\xce\x01\n\x0fPackedParticles\x12\x0f\n\x07parent1\x18\x01 \x03(\x04\x12\x0f\n\x07parent2\x18\x02 \x03(\x04\x12\x0e\n\x06\x63hild1\x18\x03 \x03(\x04\x12\x0e\n\x06\x63hild2\x18\x04 \x03(\x04\x12\x0b\n\x03pdg\x18\x05 \x03(\x11\x12\t\n\x01x\x18\x06 \x03(\x02\x12\t\n\x01y\x18\x07 \x03(\x02\x12\t\n\x01z\x18\x08 \x03(\x02\x12\t\n\x01t\x18\t \x03(\x02\x12\n\n\x02px\x18\n \x03(\x02\x12\n\n\x02py\x18\x0b \x03(\x02\x12\n\n\x02pz\x18\x0c \x03(\x02\x12\x0c\n\x04mass\x18\r \x03(\x02\x12\x0e\n\x06\x63harge\x18\x0e \x03(\x11\"\xd4\x01\n\x15VarintPackedParticles\x12\x0f\n\x07parent1\x18\x01 \x03(\x04\x12\x0f\n\x07parent2\x18\x02 \x03(\x04\x12\x0e\n\x06\x63hild1\x18\x03 \x03(\x04\x12\x0e\n\x06\x63hild2\x18\x04 \x03(\x04\x12\x0b\n\x03pdg\x18\x05 \x03(\x11\x12\t\n\x01x\x18\x06 \x03(\x11\x12\t\n\x01y\x18\x07 \x03(\x11\x12\t\n\x01z\x18\x08 \x03(\x11\x12\t\n\x01t\x18\t \x03(\x11\x12\n\n\x02px\x18\n \x03(\x11\x12\n\n\x02py\x18\x0b \x03(\x11\x12\n\n\x02pz\x18\x0c \x03(\x11\x12\x0c\n\x04mass\x18\r \x03(\r\x12\x0e\n\x06\x63harge\x18\x0e \x03(\x11\"3\n\x05XYZTD\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\t\n\x01t\x18\x04 \x01(\x01\"3\n\x05XYZTF\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01t\x18\x04 \x01(\x02\"3\n\x05XYZTL\x12\t\n\x01x\x18\x01 \x01(\x12\x12\t\n\x01y\x18\x02 \x01(\x12\x12\t\n\x01z\x18\x03 \x01(\x12\x12\t\n\x01t\x18\x04 \x01(\x12\"3\n\x05XYZTI\x12\t\n\x01x\x18\x01 \x01(\x11\x12\t\n\x01y\x18\x02 \x01(\x11\x12\t\n\x01z\x18\x03 \x01(\x11\x12\t\n\x01t\x18\x04 \x01(\x11\"\'\n\x04XYZD\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"\'\n\x04XYZF\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"\'\n\x04XYZL\x12\t\n\x01x\x18\x01 \x01(\x12\x12\t\n\x01y\x18\x02 \x01(\x12\x12\t\n\x01z\x18\x03 \x01(\x12\"\'\n\x04XYZI\x12\t\n\x01x\x18\x01 \x01(\x11\x12\t\n\x01y\x18\x02 \x01(\x11\x12\t\n\x01z\x18\x03 \x01(\x11\x42\x1f\n\x0bproio.modelB\x07\x45xampleZ\x07\x65xampleb\x06proto3')
)




_PARTICLE = _descriptor.Descriptor(
  name='Particle',
  full_name='proio.model.example.Particle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='proio.model.example.Particle.parent', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child', full_name='proio.model.example.Particle.child', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdg', full_name='proio.model.example.Particle.pdg', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertex', full_name='proio.model.example.Particle.vertex', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p', full_name='proio.model.example.Particle.p', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.example.Particle.mass', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.example.Particle.charge', index=6,
      number=7, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=225,
)


_VARINTPARTICLE = _descriptor.Descriptor(
  name='VarintParticle',
  full_name='proio.model.example.VarintParticle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='proio.model.example.VarintParticle.parent', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child', full_name='proio.model.example.VarintParticle.child', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdg', full_name='proio.model.example.VarintParticle.pdg', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertex', full_name='proio.model.example.VarintParticle.vertex', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p', full_name='proio.model.example.VarintParticle.p', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.example.VarintParticle.mass', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.example.VarintParticle.charge', index=6,
      number=7, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=400,
)


_PACKEDPARTICLES = _descriptor.Descriptor(
  name='PackedParticles',
  full_name='proio.model.example.PackedParticles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent1', full_name='proio.model.example.PackedParticles.parent1', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent2', full_name='proio.model.example.PackedParticles.parent2', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child1', full_name='proio.model.example.PackedParticles.child1', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child2', full_name='proio.model.example.PackedParticles.child2', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdg', full_name='proio.model.example.PackedParticles.pdg', index=4,
      number=5, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.example.PackedParticles.x', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.example.PackedParticles.y', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.example.PackedParticles.z', index=7,
      number=8, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t', full_name='proio.model.example.PackedParticles.t', index=8,
      number=9, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='px', full_name='proio.model.example.PackedParticles.px', index=9,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='py', full_name='proio.model.example.PackedParticles.py', index=10,
      number=11, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pz', full_name='proio.model.example.PackedParticles.pz', index=11,
      number=12, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.example.PackedParticles.mass', index=12,
      number=13, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.example.PackedParticles.charge', index=13,
      number=14, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=609,
)


_VARINTPACKEDPARTICLES = _descriptor.Descriptor(
  name='VarintPackedParticles',
  full_name='proio.model.example.VarintPackedParticles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent1', full_name='proio.model.example.VarintPackedParticles.parent1', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent2', full_name='proio.model.example.VarintPackedParticles.parent2', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child1', full_name='proio.model.example.VarintPackedParticles.child1', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child2', full_name='proio.model.example.VarintPackedParticles.child2', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdg', full_name='proio.model.example.VarintPackedParticles.pdg', index=4,
      number=5, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.example.VarintPackedParticles.x', index=5,
      number=6, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.example.VarintPackedParticles.y', index=6,
      number=7, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.example.VarintPackedParticles.z', index=7,
      number=8, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t', full_name='proio.model.example.VarintPackedParticles.t', index=8,
      number=9, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='px', full_name='proio.model.example.VarintPackedParticles.px', index=9,
      number=10, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='py', full_name='proio.model.example.VarintPackedParticles.py', index=10,
      number=11, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pz', full_name='proio.model.example.VarintPackedParticles.pz', index=11,
      number=12, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.example.VarintPackedParticles.mass', index=12,
      number=13, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.example.VarintPackedParticles.charge', index=13,
      number=14, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=824,
)


_XYZTD = _descriptor.Descriptor(
  name='XYZTD',
  full_name='proio.model.example.XYZTD',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.example.XYZTD.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.example.XYZTD.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.example.XYZTD.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t', full_name='proio.model.example.XYZTD.t', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=877,
)


_XYZTF = _descriptor.Descriptor(
  name='XYZTF',
  full_name='proio.model.example.XYZTF',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.example.XYZTF.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.example.XYZTF.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.example.XYZTF.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t', full_name='proio.model.example.XYZTF.t', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=879,
  serialized_end=930,
)


_XYZTL = _descriptor.Descriptor(
  name='XYZTL',
  full_name='proio.model.example.XYZTL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.example.XYZTL.x', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.example.XYZTL.y', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.example.XYZTL.z', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t', full_name='proio.model.example.XYZTL.t', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=983,
)


_XYZTI = _descriptor.Descriptor(
  name='XYZTI',
  full_name='proio.model.example.XYZTI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.example.XYZTI.x', index=0,
      number=1, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.example.XYZTI.y', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.example.XYZTI.z', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t', full_name='proio.model.example.XYZTI.t', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=985,
  serialized_end=1036,
)


_XYZD = _descriptor.Descriptor(
  name='XYZD',
  full_name='proio.model.example.XYZD',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.example.XYZD.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.example.XYZD.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.example.XYZD.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1077,
)


_XYZF = _descriptor.Descriptor(
  name='XYZF',
  full_name='proio.model.example.XYZF',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.example.XYZF.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.example.XYZF.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.example.XYZF.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1079,
  serialized_end=1118,
)


_XYZL = _descriptor.Descriptor(
  name='XYZL',
  full_name='proio.model.example.XYZL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.example.XYZL.x', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.example.XYZL.y', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.example.XYZL.z', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1120,
  serialized_end=1159,
)


_XYZI = _descriptor.Descriptor(
  name='XYZI',
  full_name='proio.model.example.XYZI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.example.XYZI.x', index=0,
      number=1, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.example.XYZI.y', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.example.XYZI.z', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1200,
)

_PARTICLE.fields_by_name['vertex'].message_type = _XYZTF
_PARTICLE.fields_by_name['p'].message_type = _XYZF
_VARINTPARTICLE.fields_by_name['vertex'].message_type = _XYZTI
_VARINTPARTICLE.fields_by_name['p'].message_type = _XYZI
DESCRIPTOR.message_types_by_name['Particle'] = _PARTICLE
DESCRIPTOR.message_types_by_name['VarintParticle'] = _VARINTPARTICLE
DESCRIPTOR.message_types_by_name['PackedParticles'] = _PACKEDPARTICLES
DESCRIPTOR.message_types_by_name['VarintPackedParticles'] = _VARINTPACKEDPARTICLES
DESCRIPTOR.message_types_by_name['XYZTD'] = _XYZTD
DESCRIPTOR.message_types_by_name['XYZTF'] = _XYZTF
DESCRIPTOR.message_types_by_name['XYZTL'] = _XYZTL
DESCRIPTOR.message_types_by_name['XYZTI'] = _XYZTI
DESCRIPTOR.message_types_by_name['XYZD'] = _XYZD
DESCRIPTOR.message_types_by_name['XYZF'] = _XYZF
DESCRIPTOR.message_types_by_name['XYZL'] = _XYZL
DESCRIPTOR.message_types_by_name['XYZI'] = _XYZI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Particle = _reflection.GeneratedProtocolMessageType('Particle', (_message.Message,), dict(
  DESCRIPTOR = _PARTICLE,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.Particle)
  ))
_sym_db.RegisterMessage(Particle)

VarintParticle = _reflection.GeneratedProtocolMessageType('VarintParticle', (_message.Message,), dict(
  DESCRIPTOR = _VARINTPARTICLE,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.VarintParticle)
  ))
_sym_db.RegisterMessage(VarintParticle)

PackedParticles = _reflection.GeneratedProtocolMessageType('PackedParticles', (_message.Message,), dict(
  DESCRIPTOR = _PACKEDPARTICLES,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.PackedParticles)
  ))
_sym_db.RegisterMessage(PackedParticles)

VarintPackedParticles = _reflection.GeneratedProtocolMessageType('VarintPackedParticles', (_message.Message,), dict(
  DESCRIPTOR = _VARINTPACKEDPARTICLES,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.VarintPackedParticles)
  ))
_sym_db.RegisterMessage(VarintPackedParticles)

XYZTD = _reflection.GeneratedProtocolMessageType('XYZTD', (_message.Message,), dict(
  DESCRIPTOR = _XYZTD,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.XYZTD)
  ))
_sym_db.RegisterMessage(XYZTD)

XYZTF = _reflection.GeneratedProtocolMessageType('XYZTF', (_message.Message,), dict(
  DESCRIPTOR = _XYZTF,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.XYZTF)
  ))
_sym_db.RegisterMessage(XYZTF)

XYZTL = _reflection.GeneratedProtocolMessageType('XYZTL', (_message.Message,), dict(
  DESCRIPTOR = _XYZTL,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.XYZTL)
  ))
_sym_db.RegisterMessage(XYZTL)

XYZTI = _reflection.GeneratedProtocolMessageType('XYZTI', (_message.Message,), dict(
  DESCRIPTOR = _XYZTI,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.XYZTI)
  ))
_sym_db.RegisterMessage(XYZTI)

XYZD = _reflection.GeneratedProtocolMessageType('XYZD', (_message.Message,), dict(
  DESCRIPTOR = _XYZD,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.XYZD)
  ))
_sym_db.RegisterMessage(XYZD)

XYZF = _reflection.GeneratedProtocolMessageType('XYZF', (_message.Message,), dict(
  DESCRIPTOR = _XYZF,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.XYZF)
  ))
_sym_db.RegisterMessage(XYZF)

XYZL = _reflection.GeneratedProtocolMessageType('XYZL', (_message.Message,), dict(
  DESCRIPTOR = _XYZL,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.XYZL)
  ))
_sym_db.RegisterMessage(XYZL)

XYZI = _reflection.GeneratedProtocolMessageType('XYZI', (_message.Message,), dict(
  DESCRIPTOR = _XYZI,
  __module__ = 'proio.model.example.example_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.example.XYZI)
  ))
_sym_db.RegisterMessage(XYZI)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
